@@ -19,7 +19,8 @@ from filelock import FileLock
 from ... import exceptions, helpers, utils
 from ...conf import settings
 from ...logging import logger
-from ...models.base import FileResource
+from ...models.base import FileFieldResource
+from ...models.mixins import BacklinkModelMixin
 from .mixins import ReadonlyCloudinaryFileProxyMixin
 
 
@@ -158,33 +159,10 @@ class CloudinaryFieldFile(FileProxyMixin):
             yield data
 
 
-class CloudinaryFileResource(ReadonlyCloudinaryFileProxyMixin, FileResource):
-    class Meta(FileResource.Meta):
+class CloudinaryFileFieldResourceMixin(ReadonlyCloudinaryFileProxyMixin):
+    class Meta:
         abstract = True
 
-    @property
-    def name(self) -> str:
-        self._require_file()
-        return self.get_file().name
-
-    def get_file_folder(self) -> str:
-        """
-        Возвращает путь к папке, в которую будет сохранен файл.
-        Результат вызова используется в параметре `folder` для Cloudinary.
-        """
-        return ""
-
-    def get_file(self) -> CloudinaryFieldFile:
-        raise NotImplementedError
-
-    def get_file_size(self) -> int:
-        self._require_file()
-        return self.get_file().size
-
-    def get_file_url(self) -> str:
-        self._require_file()
-        return self.get_file().url
-
     def file_exists(self) -> bool:
         file = self.get_file()
         if not file:
@@ -209,9 +187,10 @@ class CloudinaryFileResource(ReadonlyCloudinaryFileProxyMixin, FileResource):
         options.update(file_field.options)
 
         # owner field`s options should override `CloudinaryField` options
-        owner_field = self.get_owner_field()
-        if owner_field is not None and hasattr(owner_field, "cloudinary"):
-            options.update(owner_field.cloudinary or {})
+        if isinstance(self, BacklinkModelMixin):
+            owner_field = self.get_owner_field()
+            if owner_field is not None and hasattr(owner_field, "cloudinary"):
+                options.update(owner_field.cloudinary or {})
 
         # filter keys
         options = {
@@ -229,7 +208,7 @@ class CloudinaryFileResource(ReadonlyCloudinaryFileProxyMixin, FileResource):
 
         return options
 
-    def _attach_file(self, file: File, **options):
+    def _attach(self, file: File, **options):
         cloudinary_options = self.get_cloudinary_options()
         cloudinary_options.update(options.get("cloudinary", {}))
 
@@ -248,9 +227,9 @@ class CloudinaryFileResource(ReadonlyCloudinaryFileProxyMixin, FileResource):
                 **cloudinary_options,
             )
         except cloudinary.exceptions.Error as e:
-            if e.args and "Unsupported file type" in e.args[0]:
-                raise exceptions.UnsupportedFileError(
-                    _("File `%s` is not an image") % file.name
+            if e.args and "Unsupported" in e.args[0]:
+                raise exceptions.UnsupportedResource(
+                    _("File `%s` may be corrupt, or in an unsupported format.") % file.name
                 )
             else:
                 raise ValidationError(*e.args)
@@ -275,11 +254,11 @@ class CloudinaryFileResource(ReadonlyCloudinaryFileProxyMixin, FileResource):
 
         self.set_file(resource)
 
-        self.basename = helpers.get_filename(file.name)
+        self.resource_name = helpers.get_filename(file.name)
         self.extension = file_format or ""
         return result
 
-    def _rename_file(self, new_name: str, **options):
+    def _rename(self, new_name: str, **options):
         # TODO: Cloudinary can't copy files. We dont't want to do it manually
         cloudinary_options = self.get_cloudinary_options()
         cloudinary_options.update(options.get("cloudinary", {}))
@@ -324,7 +303,7 @@ class CloudinaryFileResource(ReadonlyCloudinaryFileProxyMixin, FileResource):
         )
         self.set_file(resource)
 
-        self.basename = helpers.get_filename(new_name)
+        self.resource_name = helpers.get_filename(new_name)
         self.extension = file_format or ""
         return result
 
