@@ -5,11 +5,13 @@ from django.db import models
 from django.utils.translation import gettext_lazy as _
 
 from ...conf import settings
+from ...models.base import FileFieldResource
+from ...models.mixins import BacklinkModelMixin
 from ...utils import filesizeformat
-from .base import CloudinaryFieldFile, CloudinaryFileResource
+from .base import CloudinaryFieldFile, CloudinaryFileFieldResourceMixin
 
 
-class CloudinaryFile(CloudinaryFileResource):
+class CloudinaryFile(BacklinkModelMixin, CloudinaryFileFieldResourceMixin, FileFieldResource):
     file = CloudinaryField(
         _("file"),
         type=settings.CLOUDINARY_TYPE,
@@ -17,33 +19,31 @@ class CloudinaryFile(CloudinaryFileResource):
     )
     display_name = models.CharField(_("display name"), max_length=255, blank=True)
 
-    class Meta(CloudinaryFileResource.Meta):
+    class Meta(FileFieldResource.Meta):
         verbose_name = _("file")
         verbose_name_plural = _("files")
 
-    def get_file_folder(self) -> str:
-        return settings.FILES_UPLOAD_TO
+    def save(self, *args, **kwargs):
+        if not self.pk and not self.display_name:
+            self.display_name = self.resource_name
+        super().save(*args, **kwargs)
 
     def get_file(self) -> Optional[CloudinaryFieldFile]:
         if not self.file:
             return None
         return CloudinaryFieldFile(self.file, checksum=self.checksum)
 
-    def set_file(self, value):
-        self.file = value
+    def get_file_folder(self) -> str:
+        owner_field = self.get_owner_field()
+        return getattr(owner_field, "upload_to", "") or settings.FILES_UPLOAD_TO
 
     def get_file_field(self) -> CloudinaryField:
         return self._meta.get_field("file")
 
-    def save(self, *args, **kwargs):
-        if not self.pk and not self.display_name:
-            self.display_name = self.basename
-        super().save(*args, **kwargs)
-
     def as_dict(self) -> Dict[str, Any]:
         return {
             **super().as_dict(),
-            "name": self.display_name,
+            "name": self.display_name or self.resource_name,
             "file_info": "({ext}, {size})".format(
                 ext=self.extension, size=filesizeformat(self.size)
             ),
