@@ -1,10 +1,12 @@
 from .collection import CollectionField, CollectionItem
 from .file import FileField
+from .svg import SVGFileField
 from .image import ImageField, VariationalFileField
 
 __all__ = [
     "VariationalFileField",
     "FileField",
+    "SVGFileField",
     "ImageField",
     "CollectionField",
     "CollectionItem",
